==> ep-framework-core-1.0.0-82685c.tar: src/Http/AbstractHttpClientFactory.php <==
<?php
namespace Ep\Http;

use Ep\Http\Middleware\Cache;
use GuzzleHttp\Client as HttpClient;
use GuzzleHttp\ClientInterface as HttpClientInterface;
use GuzzleHttp\Handler\CurlHandler;
use GuzzleHttp\HandlerStack;
use Interop\Container\ContainerInterface;
use Psr\Cache\CacheItemPoolInterface;
use Zend\ServiceManager\Factory\AbstractFactoryInterface;

/**
 * Stvara novu instancu http klijenta definiranog u konfiguraciji.
 *
 * @package Ep\Http
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-framework
 */
class AbstractHttpClientFactory implements AbstractFactoryInterface
{
    const CONFIG_KEY = 'http_clients';

    /** @var array */
    private $config;

    /**
     * Stvara novog http klijenta.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return HttpClientInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $options ?? $this->getConfig($container)[$requestedName] ?? [];

        $handler = new CurlHandler();
        $stack = HandlerStack::create($handler);

        if (isset($config['cache']) && !empty($config['cache'])) {
            $cache = $config['cache'];

            if (!$cache instanceof CacheItemPoolInterface) {
                /** @var CacheItemPoolInterface $cache */
                $cache = $container->get($config['cache']);
            }

            $stack->push(new Cache($cache));
            unset($config['cache']);
        }

        $config['handler'] = $stack;

        return new HttpClient($config);
    }

    /**
     * Da li imamo konfiguraciju za dato ime?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     *
     * @return bool
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        if ('config' === $requestedName) {
            return false;
        }

        $config = $this->getConfig($container);

        if (empty($config)) {
            return false;
        }

        return isset($config[$requestedName]);
    }

    /**
     * Izvlači konfiguracije http klijenata iz datog containera.
     *
     * @param ContainerInterface $container
     *
     * @return array
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    protected function getConfig(ContainerInterface $container)
    {
        if (null === $this->config) {
            $this->config = $container->has('config')
                ? $container->get('config')[self::CONFIG_KEY] ?? []
                : [];
        }

        return $this->config;
    }
}

==> ep-framework-core-2.1.1-b8606c.tar: src/Http/AbstractHttpClientFactory.php <==
<?php
namespace Ep\Http;

use Ep\Http\Middleware\Cache;
use Ep\Http\Validator\ValidatorChainFactory;
use GuzzleHttp\Client as HttpClient;
use GuzzleHttp\ClientInterface as HttpClientInterface;
use GuzzleHttp\Handler\CurlHandler;
use GuzzleHttp\HandlerStack;
use Interop\Container\ContainerInterface;
use Psr\Cache\CacheItemPoolInterface;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Stvara novu instancu http klijenta definiranog u konfiguraciji.
 *
 * @package Ep\Http
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/core
 */
class AbstractHttpClientFactory implements FactoryInterface
{
    const CONFIG_KEY = 'http_clients';

    /** @var array */
    private $config;

    /**
     * Stvara novog http klijenta.
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     *
     * @return HttpClientInterface
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $options ?? $this->getConfig($container)[$requestedName] ?? [];

        $handler = $options['handler'] ?? new CurlHandler();
        $stack = HandlerStack::create($handler);

        if (isset($config['validators'])) {
            $factory = new ValidatorChainFactory();
            $validator = $factory($container, '', [
                'validators' => $config['validators'],
            ]);

            $stack->unshift($validator);
            unset($config['validators']);
        }

        if (isset($config['cache']) && !empty($config['cache'])) {
            $cache = $config['cache'];

            if (!$cache instanceof CacheItemPoolInterface) {
                /** @var CacheItemPoolInterface $cache */
                $cache = $container->get($config['cache']);
            }

            $stack->push(new Cache($cache, $config['cache_lifetime'] ?? 0));
            unset($config['cache']);
        }

        foreach (($config['stack'] ?? []) as $handler) {
            if (is_string($handler)) {
                if (!$container->has($handler)) {
                    throw new ServiceNotCreatedException(
                        sprintf('Guzzle handler s imenom `%s` ne postoji u containeru.', $handler)
                    );
                }

                $handler = $container->get($handler);
            }

            $stack->push($handler);
        }

        $config['handler'] = $stack;

        if (!isset($config['http_errors'])) {
            $config['http_errors'] = false;
        }

        return new HttpClient($config);
    }

    /**
     * Da li imamo konfiguraciju za dato ime?
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     *
     * @return bool
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    public function canCreate(ContainerInterface $container, $requestedName)
    {
        if ('config' === $requestedName) {
            return false;
        }

        $config = $this->getConfig($container);

        if (empty($config)) {
            return false;
        }

        return isset($config[$requestedName]);
    }

    /**
     * Izvlači konfiguracije http klijenata iz datog containera.
     *
     * @param ContainerInterface $container
     *
     * @return array
     *
     * @throws \Psr\Container\ContainerExceptionInterface
     * @throws \Psr\Container\NotFoundExceptionInterface
     */
    protected function getConfig(ContainerInterface $container)
    {
        if (null === $this->config) {
            $this->config = $container->has('config')
                ? $container->get('config')[self::CONFIG_KEY] ?? []
                : [];
        }

        return $this->config;
    }
}
